Livefyre Python Utility Classes
===============================

|Circle CI| |PyPI version| |Coverage Status|

Livefyre’s official library for common server-side tasks necessary for
getting Livefyre apps (comments, reviews, etc.) working on your website.

Works with Python versions: 2.6, 2.7, 3.2, 3.3

Installation
------------

Run this line:

::

    $ pip install livefyre

Documentation
-------------

Located `here`_.

Contributing
------------

1. Fork it
2. Create your feature branch (``git checkout -b my-new-feature``)
3. Commit your changes (``git commit -am 'Add some feature'``)
4. Push to the branch (``git push origin my-new-feature``)
5. Create new Pull Request

Note: any feature update on any of Livefyre’s libraries will need to be
reflected on all libraries. We will try and accommodate when we find a
request useful, but please be aware of the time it may take.

License
-------

MIT

.. _here: http://answers.livefyre.com/developers/libraries

.. |Circle CI| image:: https://circleci.com/gh/Livefyre/livefyre-python-utils.png?style=badge
   :target: https://circleci.com/gh/Livefyre/livefyre-python-utils
.. |PyPI version| image:: https://badge.fury.io/py/livefyre.png
   :target: http://badge.fury.io/py/livefyre
.. |Coverage Status| image:: https://coveralls.io/repos/Livefyre/livefyre-python-utils/badge.png
   :target: https://coveralls.io/r/Livefyre/livefyre-python-utils